# -*- coding: utf-8 -*-

# Authors: Natalia B Bidart <natalia.bidart@canonical.com>
#
# Copyright 2010 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""The test suite for the control panel user interface."""

import gtk

from twisted.trial.unittest import TestCase

from ubuntuone.control_panel import gui, utils


class FakedBuilder(object):
    """A faked builder."""

    def __init__(self):
        self.add_from_file = lambda fname: setattr(self, 'filename', fname)
        self.connect_signals = lambda arg: setattr(self, 'signals', arg)
        self.get_objects = lambda: []


class BasicControlPanelUITestCase(TestCase):
    """The basic test suite for the control panel user interface."""

    def setUp(self):
        self._called = False

    def _set_called(self, *args, **kwargs):
        """Store 'args' and 'kwargs' for test assertions."""
        self._called = (args, kwargs)

    def test_ui_can_be_created(self):
        """UI main class exists and can be created."""
        ui = gui.ControlPanelUI()
        self.assertTrue(ui is not None)

    def test_main_start_gtk_main_loop(self):
        """The GTK main loop is started when calling main()."""
        ui = gui.ControlPanelUI()
        self.patch(gtk, 'main', self._set_called)
        ui.main()
        self.assertEqual(self._called, ((), {}), 'gtk.main was called.')

    def test_ui_file_is_read_at_startup(self):
        """The ui file is read and parse at startup."""
        self.patch(gtk, 'Builder', FakedBuilder)
        ui = gui.ControlPanelUI()
        self.assertEqual(ui.builder.filename, utils.get_data_file('main.ui'))

    def test_signals_are_connected_at_startup(self):
        """The signals are connectedt at startup."""
        self.patch(gtk, 'Builder', FakedBuilder)
        ui = gui.ControlPanelUI()
        self.assertEqual(ui.builder.signals, ui.builder)
